==> deepin-camera_6.5.5.tar.xz: BUILD/src/translations/deepin-camera_sl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl">
<context>
    <name>CMainWindow</name>
    <message>
        <source>Video recording is in progress. Close the window?</source>
        <translation>Video se snema. Naj zaprem okno?</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation type="vanished">Odpri mapo</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Nastavitve</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Brez</translation>
    </message>
    <message>
        <source>Photo</source>
        <translation>Slika</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Switch Cameras</source>
        <translation>Zamenjaj kamere</translation>
    </message>
</context>
<context>
    <name>CloseDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Prekini</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Zapri</translation>
    </message>
</context>
<context>
    <name>ImageItem</name>
    <message>
        <source>Copy</source>
        <translation>Kopiraj</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Izbriši</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Odpri mapo</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Tiskanje</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>Za to mapo nimate pravic</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Zapri</translation>
    </message>
    <message>
        <source>Invalid folder</source>
        <translation type="vanished">Neveljavna mapa</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Odpri mapo</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Nastavitve</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>Osnovno</translation>
    </message>
    <message>
        <source>File location</source>
        <translation>Lokacija datoteke</translation>
    </message>
    <message>
        <source>Shoot</source>
        <translation>Slikaj</translation>
    </message>
    <message>
        <source>Burst mode</source>
        <translation>Zaporedje posnetkov</translation>
    </message>
    <message>
        <source>Self-timer delay</source>
        <translation>Časovni zamik</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>Izhod</translation>
    </message>
    <message>
        <source>Output format</source>
        <translation>Izhodni format</translation>
    </message>
    <message>
        <source>4 pcs</source>
        <translation>4 kosi</translation>
    </message>
    <message>
        <source>10 pcs</source>
        <translation>10 kosov</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Brez</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Camera is an image and video capture utility using your PC camera or webcam.</source>
        <translation>Kamera je orodje za zajem slik in videa, ki uporablja PC ali spletno kamero.</translation>
    </message>
    <message>
        <source>File not saved</source>
        <translation>Datoteka ni shranjena</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation type="vanished">Shrani v:</translation>
    </message>
    <message>
        <source>Photo:</source>
        <translation>Fotografija:</translation>
    </message>
    <message>
        <source>Video:</source>
        <translation>Video:</translation>
    </message>
    <message>
        <source>Resolution settings</source>
        <translation>Nastavitve ločljivosti</translation>
    </message>
    <message>
        <source>Resolution:</source>
        <translation type="vanished">Ločljivost</translation>
    </message>
    <message>
        <source>Photos:</source>
        <translation>Fotografije:</translation>
    </message>
    <message>
        <source>Videos:</source>
        <translation>Video posnetki:</translation>
    </message>
    <message>
        <source>Sound effects</source>
        <translation>Zvočni učinki</translation>
    </message>
    <message>
        <source>Mirror mode</source>
        <translation>Način zrcaljenja</translation>
    </message>
    <message>
        <source>Flashlight</source>
        <translation>Bliskavica</translation>
    </message>
    <message>
        <source>Gridlines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1*1 lines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>2*2 lines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Maximum resolution:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Nastavitve</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>Zaustavi snemanje</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopiraj</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Izbriši</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Odpri</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Tiskanje</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Pomoč</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Prikaži bljižnice</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>Zaustavi slikanje</translation>
    </message>
    <message>
        <source>Context menu</source>
        <translation>Kontekstualni meni</translation>
    </message>
</context>
<context>
    <name>ThumbnailsBar</name>
    <message>
        <source>Take photo</source>
        <translation type="vanished">Slikaj</translation>
    </message>
    <message>
        <source>Record video</source>
        <translation type="vanished">Snemaj</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation type="vanished">Zaustavi slikanje</translation>
    </message>
</context>
<context>
    <name>dc::Settings</name>
    <message>
        <source>None</source>
        <translation>Brez</translation>
    </message>
</context>
<context>
    <name>filterPreviewButton</name>
    <message>
        <source>Normal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Vivid</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Warm</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cold</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Retro</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Film</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Gray</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>B&amp;W</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>takePhotoSettingAreaWidget</name>
    <message>
        <source>Flashlight</source>
        <translation>Bliskavica</translation>
    </message>
    <message>
        <source>On</source>
        <translation>Vklopljeno</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Izklopljeno</translation>
    </message>
    <message>
        <source>Delay capture</source>
        <translation>Zamik zajema</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Brez</translation>
    </message>
    <message>
        <source>Filters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exposure</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>videowidget</name>
    <message>
        <source>No webcam found</source>
        <translation>Ni spletne kamere</translation>
    </message>
    <message>
        <source>The webcam is in use</source>
        <translation>Spletna kamera je že v rabi</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation type="vanished">Zaustavi snemanje</translation>
    </message>
</context>
</TS>

==> deepin-camera_6.5.16.tar.xz: BUILD/src/translations/deepin-camera_sl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sl">
<context>
    <name>CMainWindow</name>
    <message>
        <source>Video recording is in progress. Close the window?</source>
        <translation>Video se snema. Naj zaprem okno?</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation type="vanished">Odpri mapo</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Nastavitve</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Brez</translation>
    </message>
    <message>
        <source>Photo</source>
        <translation>Slika</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Switch Cameras</source>
        <translation>Zamenjaj kamere</translation>
    </message>
</context>
<context>
    <name>CloseDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Prekini</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Zapri</translation>
    </message>
</context>
<context>
    <name>ImageItem</name>
    <message>
        <source>Copy</source>
        <translation>Kopiraj</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Izbriši</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Odpri mapo</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Tiskanje</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>Za to mapo nimate pravic</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Zapri</translation>
    </message>
    <message>
        <source>Invalid folder</source>
        <translation type="vanished">Neveljavna mapa</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Odpri mapo</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Nastavitve</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>Osnovno</translation>
    </message>
    <message>
        <source>File location</source>
        <translation>Lokacija datoteke</translation>
    </message>
    <message>
        <source>Shoot</source>
        <translation>Slikaj</translation>
    </message>
    <message>
        <source>Burst mode</source>
        <translation>Zaporedje posnetkov</translation>
    </message>
    <message>
        <source>Self-timer delay</source>
        <translation>Časovni zamik</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>Izhod</translation>
    </message>
    <message>
        <source>Output format</source>
        <translation>Izhodni format</translation>
    </message>
    <message>
        <source>4 pcs</source>
        <translation>4 kosi</translation>
    </message>
    <message>
        <source>10 pcs</source>
        <translation>10 kosov</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Brez</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Camera is an image and video capture utility using your PC camera or webcam.</source>
        <translation>Kamera je orodje za zajem slik in videa, ki uporablja PC ali spletno kamero.</translation>
    </message>
    <message>
        <source>File not saved</source>
        <translation>Datoteka ni shranjena</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation type="vanished">Shrani v:</translation>
    </message>
    <message>
        <source>Photo:</source>
        <translation>Fotografija:</translation>
    </message>
    <message>
        <source>Video:</source>
        <translation>Video:</translation>
    </message>
    <message>
        <source>Resolution settings</source>
        <translation>Nastavitve ločljivosti</translation>
    </message>
    <message>
        <source>Resolution:</source>
        <translation type="vanished">Ločljivost</translation>
    </message>
    <message>
        <source>Photos:</source>
        <translation>Fotografije:</translation>
    </message>
    <message>
        <source>Videos:</source>
        <translation>Video posnetki:</translation>
    </message>
    <message>
        <source>Sound effects</source>
        <translation>Zvočni učinki</translation>
    </message>
    <message>
        <source>Mirror mode</source>
        <translation>Način zrcaljenja</translation>
    </message>
    <message>
        <source>Flashlight</source>
        <translation>Bliskavica</translation>
    </message>
    <message>
        <source>Gridlines</source>
        <translation>Mreža</translation>
    </message>
    <message>
        <source>1*1 lines</source>
        <translation>1*1 črt</translation>
    </message>
    <message>
        <source>2*2 lines</source>
        <translation>2*2 črt</translation>
    </message>
    <message>
        <source>Maximum resolution:</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Nastavitve</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>Zaustavi snemanje</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopiraj</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Izbriši</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Odpri</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Tiskanje</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Pomoč</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Prikaži bljižnice</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>Zaustavi slikanje</translation>
    </message>
    <message>
        <source>Context menu</source>
        <translation>Kontekstualni meni</translation>
    </message>
</context>
<context>
    <name>ThumbnailsBar</name>
    <message>
        <source>Take photo</source>
        <translation type="vanished">Slikaj</translation>
    </message>
    <message>
        <source>Record video</source>
        <translation type="vanished">Snemaj</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation type="vanished">Zaustavi slikanje</translation>
    </message>
</context>
<context>
    <name>dc::Settings</name>
    <message>
        <source>None</source>
        <translation>Brez</translation>
    </message>
</context>
<context>
    <name>filterPreviewButton</name>
    <message>
        <source>Normal</source>
        <translation>Normalno</translation>
    </message>
    <message>
        <source>Vivid</source>
        <translation>Živo</translation>
    </message>
    <message>
        <source>Warm</source>
        <translation>toplo</translation>
    </message>
    <message>
        <source>Cold</source>
        <translation>Hladno</translation>
    </message>
    <message>
        <source>Retro</source>
        <translation>Retro</translation>
    </message>
    <message>
        <source>Film</source>
        <translation>Film</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Sivo</translation>
    </message>
    <message>
        <source>B&amp;W</source>
        <translation>ČB</translation>
    </message>
</context>
<context>
    <name>takePhotoSettingAreaWidget</name>
    <message>
        <source>Flashlight</source>
        <translation>Bliskavica</translation>
    </message>
    <message>
        <source>On</source>
        <translation>Vklopljeno</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Izklopljeno</translation>
    </message>
    <message>
        <source>Delay capture</source>
        <translation>Zamik zajema</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Brez</translation>
    </message>
    <message>
        <source>Filters</source>
        <translation>Filtri</translation>
    </message>
    <message>
        <source>Exposure</source>
        <translation>Osvetlitev</translation>
    </message>
</context>
<context>
    <name>videowidget</name>
    <message>
        <source>No webcam found</source>
        <translation>Ni spletne kamere</translation>
    </message>
    <message>
        <source>The webcam is in use</source>
        <translation>Spletna kamera je že v rabi</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation type="vanished">Zaustavi snemanje</translation>
    </message>
</context>
</TS>
